metapho

Package metapho |
[hide private]

# Package metapho

source code

MetaPho: an image tagger and viewer.

Version: 0.5

Author: Akkana Peck <akkana@shallowsky.com>

License: GPL v2

Submodules | [hide private]
metapho.gtkpho: GTK UI classes for metapho: an image tagger and viewer. metapho.main: metapho: an image tagger and viewer. metapho.metapho: These are the base class for metapho images and taggers.

Classes | [hide private]
| Image An image, with additional info such as rotation and tags.
| Tagger Manages tags for images.

Variables | [hide private]
| __package__ = ``'``metapho``'``